@@ -193,6 +193,7 @@ class Extract:
         cps = self.extract['1d']['cps']
         flam = self.extract['1d']['flam']
         sensitivity = self.extract['1d']['sensitivity']
+        savefolder = self.data['savefolder']
 
         fig = plt.figure(figsize=figsize)
         ax = fig.add_subplot(4,1,1)
@@ -287,7 +288,6 @@ class Extract:
 
         fig.tight_layout()
         if save:
-            string = '{0}_spc1d.{1}'.format(self.data['objname'],saveformat) if savename_prefix is None else '{0}_spc1d.{1}'.format(savename_prefix,saveformat)
-            string = './{0}/'.format(self.data['savefolder'] + string
+            string = './{2}/{0}_spc1d.{1}'.format(self.data['objname'],saveformat,savefolder) if savename_prefix is None else './{2}/{0}_spc1d.{1}'.format(savename_prefix,saveformat,savefolder)
             fig.savefig(string,format=saveformat,bbox_inches='tight')
             print('Save {0}'.format(string))
